import { DateTime } from 'luxon';

var Operator;
(function (Operator) {
    Operator["Equals"] = "==";
    Operator["EqualsIns"] = "==*";
    Operator["NotEquals"] = "!=";
    Operator["NotEqualsIns"] = "!=*";
    Operator["GreaterThen"] = ">";
    Operator["LessThen"] = "<";
    Operator["GreaterOrEquals"] = ">=";
    Operator["LessOrEquals"] = "<=";
    Operator["Contains"] = "@=";
    Operator["ContainsIns"] = "@=*";
    Operator["NotContains"] = "!@=";
    Operator["NotContainsIns"] = "!@=*";
    Operator["StartsWith"] = "_=";
    Operator["StartsWithIns"] = "_=*";
    Operator["NotStartsWith"] = "!_=";
    Operator["NotStartsWithIns"] = "!_=*";
    Operator["EndsWith"] = "_-=";
    Operator["EndsWithIns"] = "_-=*";
    Operator["NotEndsWith"] = "!_-=";
    Operator["NotEndsWithIns"] = "!_-=*";
})(Operator || (Operator = {}));
const textOperators = [
    [Operator.EqualsIns, '=Abc'],
    // [Operator.NotEqualsIns, '!='],
    [Operator.ContainsIns, '..Abc..'],
    // [Operator.NotContainsIns, 'not _abc_'],
    [Operator.StartsWithIns, 'Abc...'],
    // [Operator.NotStartsWithIns, 'not Abc__'],
    [Operator.EndsWithIns, '...Abc'],
    // [Operator.NotEndsWithIns, 'not __abc'],
];
const numberOperators = [
    [Operator.Equals, '='],
    [Operator.NotEquals, '!='],
    // [Operator.GreaterThen, '>'],
    [Operator.GreaterOrEquals, '>'],
    // [Operator.LessThen, '<'],
    [Operator.LessOrEquals, '<'],
];
const defaultTextOperator = textOperators[1][0];
const defaultNumberOperator = numberOperators[0][0];

const postfixes = {
    textOp: '(OPTt)',
    numOp: '(OPTn)',
    endPartOp: '(END)',
    isTextOp: (op) => op.endsWith(postfixes.textOp),
    isNumOp: (op) => op.endsWith(postfixes.numOp),
    isOp: (op) => postfixes.isTextOp(op) || postfixes.isNumOp(op),
    isEnd: (op) => op.endsWith(postfixes.endPartOp),
    removeOp: (op) => op.replace(postfixes.textOp, '').replace(postfixes.numOp, ''),
    removeEnd: (op) => op.replace(postfixes.endPartOp, ''),
};
function buildFiltersQuery(options) {
    const items = Object.entries(options);
    const operators = items
        .filter(x => postfixes.isOp(x[0]))
        .map(x => [postfixes.removeOp(x[0]), x[1]]);
    const queryParts = [];
    items
        .filter(x => !postfixes.isOp(x[0]))
        .forEach(([key, value]) => {
        var _a;
        if (!value && value !== 0) {
            return;
        }
        if (value instanceof DateTime) {
            if (!value.isValid) {
                return;
            }
            if (postfixes.isEnd(key)) {
                const op = Operator.LessThen;
                value = value.plus({ day: 1 }).toISODate(); // to include the last day in the range
                queryParts.push(postfixes.removeEnd(key) + op + value);
            }
            else {
                const op = Operator.GreaterOrEquals;
                queryParts.push(key + op + value.toISODate());
            }
        }
        else {
            const op = ((_a = operators.find(x => x[0] === key)) === null || _a === void 0 ? void 0 : _a[1]) || Operator.Equals;
            queryParts.push(key + op + (value === 0 ? 0 : value || ''));
        }
    });
    console.info(queryParts.join('\n'));
    return queryParts.join(',');
}
function parseFiltersQuery(query) {
    const filters = query === null || query === void 0 ? void 0 : query.split(',');
    if (filters && filters.length > 0) {
        const result = [];
        const availableOperators = Object.values(Operator).sort(x => -x.length);
        for (const filter of filters) {
            for (const operator of availableOperators) {
                if (filter.includes(operator)) {
                    const sepIdx = filter.indexOf(operator);
                    result.push({
                        key: filter.substring(0, sepIdx),
                        op: operator,
                        val: filter.substring(sepIdx + operator.length, filter.length),
                    });
                    break;
                }
            }
        }
        return result;
    }
    return [];
}

/**
 * Generated bundle index. Do not edit.
 */

export { Operator, buildFiltersQuery, defaultNumberOperator, defaultTextOperator, numberOperators, parseFiltersQuery, postfixes, textOperators };
//# sourceMappingURL=neercms-table-sieve.mjs.map
