import { DateTime } from 'luxon';
import { getDomain } from 'neercms/shared/utilities';

function editButton(text) {
    return {
        class: 'edit',
        text: text,
        icon: 'la-edit',
    };
}
function deleteButton(text) {
    return {
        class: 'delete',
        text: text,
        icon: 'la-backspace',
    };
}

const maxStringLength = 28;
const emptyStringPlaceholder = '<span class="text-dimmed">—</span>';
function formatAsDate(value) {
    return value ? DateTime.fromISO(value).toFormat('dd/MM/yyyy HH:mm') : emptyStringPlaceholder;
}
function formatCheckmark(value) {
    if (value) {
        return '<span class="check check-true">yes</span>';
    }
    else {
        return '<span class="check check-false">no</span>';
    }
}
function formatCounter(value) {
    if (value > 0) {
        return `<span class="counter counter-positive"><i class="las la-heart"></i> ${value}</span>`;
    }
    else if (value < 0) {
        return `<span class="counter counter-negative"><i class="las la-heart"></i>️ ${-value}</span>`;
    }
    else {
        return `<span class="counter"><i class="las la-heart"></i>️ ${value}</span>`;
    }
}
function formatLink(link) {
    if (link) {
        const display = getDomain(link);
        return `<a href=\"${link}\" title=\"${link}\">${display}</a>`;
    }
    else {
        return emptyStringPlaceholder;
    }
}
function formatAsText(value) {
    return limitStringLength(value, maxStringLength, emptyStringPlaceholder);
}
function limitStringLength(sourceString, maxLength, defaultValue) {
    if (!sourceString) {
        return defaultValue;
    }
    if (sourceString.length > maxLength) {
        return sourceString.substring(0, maxLength - 3) + '...';
    }
    return sourceString;
}

/**
 * Generated bundle index. Do not edit.
 */

export { deleteButton, editButton, emptyStringPlaceholder, formatAsDate, formatAsText, formatCheckmark, formatCounter, formatLink, limitStringLength, maxStringLength };
//# sourceMappingURL=neercms-table-utilities.mjs.map
