import { MediaMatcher } from '@angular/cdk/layout';
import { DOCUMENT } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, Injectable } from '@angular/core';
import { NeerStorageService } from 'neercms/services/storage';
import { BehaviorSubject } from 'rxjs';

class ThemeService {
    constructor() {
        this.document = inject(DOCUMENT);
        this.media = inject(MediaMatcher);
        this.storage = inject(NeerStorageService);
        this.style = document.createElement('link');
        this.style.rel = 'stylesheet';
        document.head.appendChild(this.style);
        this.darkBrowserTheme = this.media.matchMedia('(prefers-color-scheme: dark)');
        this.overlayContainer = document.getElementsByTagName('body')[0];
    }
    init(themes) {
        if (!themes) {
            throw new Error('Invalid themes provided!');
        }
        this.themes = themes;
        this.darkBrowserTheme.addEventListener('change', event => {
            console.log('User changed browser theme to', event.matches ? 'dark' : 'light');
            this.setTheme(this.defaultTheme);
        });
        this.themeChange = new BehaviorSubject(this.defaultTheme);
        this.refreshTheme();
    }
    get defaultTheme() {
        const themes = Object.entries(this.themes);
        const isDark = this.darkBrowserTheme.matches;
        return themes.find(([name, theme]) => theme.styles?.dark === isDark)[0];
    }
    get currentThemeName() {
        let theme = this.storage.theme;
        if (!theme) {
            this.storage.theme = this.defaultTheme;
            return this.defaultTheme;
        }
        return theme;
    }
    get currentTheme() {
        if (!this.themes) {
            throw new Error('Themes mast be initialized before use');
        }
        return this.themes[this.currentThemeName];
    }
    refreshTheme() {
        const storedTheme = this.storage.theme || this.defaultTheme;
        if (storedTheme) {
            this.setTheme(storedTheme);
        }
    }
    setTheme(theme) {
        if (!this.themes) {
            throw new Error('Themes mast be initialized before set');
        }
        const themeInfo = this.themes[theme];
        if (themeInfo) {
            this.style.href = themeInfo.stylesheet ? `/${themeInfo.stylesheet}.css` : '';
            this.storage.theme = theme;
        }
        else {
            console.warn('Unknown theme name:', theme);
        }
    }
}
ThemeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: ThemeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ThemeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: ThemeService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.3.0", ngImport: i0, type: ThemeService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: function () { return []; } });

/**
 * Generated bundle index. Do not edit.
 */

export { ThemeService };
//# sourceMappingURL=neercms-services-theme.mjs.map
